@@ -4,6 +4,8 @@
 
 #include <CMulticalendar.h>
 
+#include "CalendarPickDialog.h"
+
 #include "CWrapper.h"
 
 CalendarPickSelector::CalendarPickSelector(QObject *parent) : QMaemo5AbstractPickSelector(parent)
@@ -12,10 +14,6 @@ CalendarPickSelector::CalendarPickSelector(QObject *parent) : QMaemo5AbstractPic
     setCalendar(1);
 }
 
-CalendarPickSelector::~CalendarPickSelector()
-{
-}
-
 void CalendarPickSelector::setCalendar(int calendarId)
 {
     int error = 0;
