@@ -3,15 +3,12 @@
 
 #include <QMaemo5AbstractPickSelector>
 
-#include "CalendarPickDialog.h"
-
 class CalendarPickSelector : public QMaemo5AbstractPickSelector
 {
     Q_OBJECT
 
 public:
     CalendarPickSelector(QObject *parent = 0);
-    ~CalendarPickSelector();
 
     QString currentValueText() const;
     int currentId() const;
