@@ -3,15 +3,61 @@
 #include <QMessageBox>
 #include <QMaemo5InformationBox>
 
+#include <QDBusConnection>
+
 #include <CalendarErrors.h>
 
 #include "EventEditDialog.h"
 #include "TodoEditDialog.h"
 #include "JournalEditDialog.h"
 
+#include "ChangeClient.h"
+
+#include "MainWindow.h"
 #include "CWrapper.h"
 
 Version ChangeManager::m_version = 1;
+QDate ChangeManager::m_date = QDate::currentDate();
+
+ChangeClient* ChangeManager::activeClient = NULL;
+QTimer* ChangeManager::dateCheckTimer;
+
+ChangeManager* ChangeManager::instance = new ChangeManager();
+
+ChangeManager::ChangeManager()
+{
+    dateCheckTimer = new QTimer(this);
+    dateCheckTimer->setInterval(10000);
+    connect(dateCheckTimer, SIGNAL(timeout()), this, SLOT(checkDate()));
+
+    QDBusConnection::sessionBus().connect("", "", DBUS_INTERFACE, "dbChange",
+                                          this, SLOT(onDbChange(QString,QString)));
+}
+
+// Start delivering change notifications to the specified client
+void ChangeManager::activateClient(ChangeClient *client)
+{
+    activeClient = client;
+
+    // Check the date, which might result in version bumping
+    checkDate();
+    dateCheckTimer->start();
+
+    // If the date check did not result in a bump and the associated onChange(),
+    // the client still might have old data, in which case onChange() still
+    // needs to be called.
+    if (client->isOutdated())
+        client->onChange();
+}
+
+// Stop change notification delivery
+void ChangeManager::deactivateClient(ChangeClient *client)
+{
+    if (activeClient == client) {
+        activeClient = NULL;
+        dateCheckTimer->stop();
+    }
+}
 
 // Return the version of tracked database state
 Version ChangeManager::version()
@@ -19,10 +65,37 @@ Version ChangeManager::version()
     return m_version;
 }
 
+// Check if an update should occur due to passing time
+void ChangeManager::checkDate()
+{
+    const QDate currentDate = QDate::currentDate();
+
+    if (m_date != currentDate) {
+        m_date = currentDate;
+        bump();
+    }
+}
+
+// Handle a database change notification from D-Bus
+void ChangeManager::onDbChange(QString details, QString appName)
+{
+    Q_UNUSED(details);
+
+    // Do not react to updates originating from this application, as they are
+    // handled internally.
+    // NOTE: This check will not recognize updates coming from a different
+    // instance of this application.
+    if (appName != CMulticalendar::MCInstance()->getApplicationName().c_str())
+        bump();
+}
+
 // Bump the database state version
 void ChangeManager::bump()
 {
     m_version++;
+
+    if (activeClient)
+        activeClient->onChange();
 }
 
 // Open the component in the appropriate editor
@@ -62,27 +135,11 @@ bool ChangeManager::drop(QWidget *parent, CComponent *component)
 
     int error;
 
-    CCalendar *calendar = CMulticalendar::MCInstance()->getCalendarById(component->getCalendarId(), error);
-
-    if (error == CALENDAR_OPERATION_SUCCESSFUL) {
-        switch (component->getType()) {
-            case E_EVENT:
-                calendar->deleteEvent(component->getId(), error);
-                break;
-            case E_TODO:
-                calendar->deleteTodo(component->getId(), error);
-                break;
-            case E_JOURNAL:
-                calendar->deleteJournal(component->getId(), error);
-                break;
-        }
-    }
-
-    delete calendar;
+    deleteComponent(component, component->getCalendarId(), error);
 
     bump();
 
-    return error == CALENDAR_OPERATION_SUCCESSFUL;
+    return true;
 }
 
 // Show editor with a new event
@@ -114,6 +171,16 @@ bool ChangeManager::newEvent(QWidget *parent, QDateTime from, QDateTime to, bool
     return ed->exec() == QDialog::Accepted;
 }
 
+// Show editor with a new task, configure deadline
+bool ChangeManager::newTodo(QWidget *parent, QDate due)
+{
+    TodoEditDialog *ed = new TodoEditDialog(parent);
+
+    ed->setDue(due);
+
+    return ed->exec() == QDialog::Accepted;
+}
+
 // Show editor with a new task
 bool ChangeManager::newTodo(QWidget *parent)
 {
@@ -140,23 +207,18 @@ bool ChangeManager::save(CComponent *component, int calendarId)
 
     // Check if the component already exists in the database
     if (component->getCalendarId()) {
-        CCalendar *calendar = CMulticalendar::MCInstance()->getCalendarById(component->getCalendarId(), error);
         if (calendarId == component->getCalendarId()) {
             // Simply save chages
-            modifyComponent(calendar, component, error);
+            modifyComponent(component, component->getCalendarId(), error);
         } else {
             // Move the component between calendars, start by removing it from the old one
-            deleteComponent(calendar, component, error);
+            deleteComponent(component, component->getCalendarId(), error);
         }
-        delete calendar;
     }
 
     // Add the component to a calendar if it is a fresh one or has to be moved
-    if (!component->getCalendarId()) {
-        CCalendar *calendar = CMulticalendar::MCInstance()->getCalendarById(calendarId, error);
-        addComponent(calendar, component, error);
-        delete calendar;
-    }
+    if (!component->getCalendarId())
+        addComponent(component, calendarId, error);
 
     bump();
 
@@ -164,53 +226,59 @@ bool ChangeManager::save(CComponent *component, int calendarId)
     return true;
 }
 
-// Add the component to the calendar (helper for the low-level save)
-void ChangeManager::addComponent(CCalendar* calendar, CComponent *component, int &error)
+// Add the component to the calendar (low-level helper)
+void ChangeManager::addComponent(CComponent *component, int calendarId, int &error)
 {
-    component->setCalendarId(calendar->getCalendarId());
+    component->setCalendarId(calendarId);
+
+    CMulticalendar *mc = CMulticalendar::MCInstance();
 
     switch (component->getType()) {
         case E_EVENT:
-            calendar->addEvent(static_cast<CEvent*>(component), error);
+            mc->addEvent(static_cast<CEvent*>(component), calendarId, error);
             break;
         case E_TODO:
-            calendar->addTodo(static_cast<CTodo*>(component), error);
+            mc->addTodo(static_cast<CTodo*>(component), calendarId, error);
             break;
         case E_JOURNAL:
-            calendar->addJournal(static_cast<CJournal*>(component), error);
+            mc->addJournal(static_cast<CJournal*>(component), calendarId, error);
             break;
         // TODO: Set error if the type cannot be handled?
     }
 }
 
-// Modify the component belonging the calendar (helper for the low-level save)
-void ChangeManager::modifyComponent(CCalendar* calendar, CComponent *component, int &error)
+// Modify the component belonging to the calendar (low-level helper)
+void ChangeManager::modifyComponent(CComponent *component, int calendarId, int &error)
 {
+    CMulticalendar *mc = CMulticalendar::MCInstance();
+
     switch (component->getType()) {
         case E_EVENT:
-            calendar->modifyEvent(static_cast<CEvent*>(component), error);
+            mc->modifyEvent(static_cast<CEvent*>(component), calendarId, error);
             break;
         case E_TODO:
-            calendar->modifyTodo(static_cast<CTodo*>(component), error);
+            mc->modifyTodo(static_cast<CTodo*>(component), calendarId, error);
             break;
         case E_JOURNAL:
-            calendar->modifyJournal(static_cast<CJournal*>(component), error);
+            mc->modifyJournal(static_cast<CJournal*>(component), calendarId, error);
             break;
     }
 }
 
-// Delete the component from the calendar (helper for the low-level save)
-void ChangeManager::deleteComponent(CCalendar *calendar, CComponent *component, int &error)
+// Delete the component from the calendar (low-level helper)
+void ChangeManager::deleteComponent(CComponent *component, int calendarId, int &error)
 {
+    CMulticalendar *mc = CMulticalendar::MCInstance();
+
     switch (component->getType()) {
         case E_EVENT:
-            calendar->deleteEvent(component->getId(), error);
+            mc->deleteEvent(calendarId, component->getId(), error);
             break;
         case E_TODO:
-            calendar->deleteTodo(component->getId(), error);
+            mc->deleteTodo(calendarId, component->getId(), error);
             break;
         case E_JOURNAL:
-            calendar->deleteJournal(component->getId(), error);
+            mc->deleteJournal(calendarId, component->getId(), error);
             break;
     }
 
