@@ -5,10 +5,6 @@
 
 #include "ui_JournalsPlug.h"
 
-namespace Ui {
-    class JournalsPlug;
-}
-
 class JournalsPlug : public Plug
 {
     Q_OBJECT
@@ -20,7 +16,7 @@ public:
     QString title() const;
     bool isRotatable() const { return true; }
 
-    void onActivated();
+    void onChange();
 
 private:
     Ui::JournalsPlug *ui;
