@@ -15,9 +15,17 @@ public:
     QList<QAction*> actions;
 
     virtual QString title() const = 0;
-    virtual bool isRotatable() const { return false; };
+    virtual bool isRotatable() const { return false; }
 
-    virtual void onActivated() { };
+    virtual void onActivated()
+    {
+        this->activate();
+    }
+
+    virtual void onDeactivated()
+    {
+        this->deactivate();
+    }
 
 signals:
     void titleChanged(QString title);
