@@ -6,10 +6,6 @@
 
 #include <CTodo.h>
 
-namespace Ui {
-    class TodoEditDialog;
-}
-
 class TodoEditDialog : public ComponentEditDialog
 {
     Q_OBJECT
@@ -18,11 +14,14 @@ public:
     TodoEditDialog(QWidget *parent, CTodo *todo = NULL);
     ~TodoEditDialog();
 
+    void setDue(QDate due);
+
 private:
     Ui::TodoEditDialog *ui;
 
     CTodo *todo;
 
+    bool defaultDue;
     time_t alarmOffset;
 
 private slots:
