@@ -53,20 +53,26 @@ TodoWindow::~TodoWindow()
 
 void TodoWindow::changeEvent(QEvent *e)
 {
-    if (e->type() == QEvent::ActivationChange
-    &&  this->isActiveWindow()
-    &&  this->isOutdated())
-    {
-        CTodo *outdatedTodo = todo;
-        todo = CWrapper::details(todo);
-        delete outdatedTodo;
-
-        reload();
+    if (e->type() == QEvent::ActivationChange) {
+        if (this->isActiveWindow()) {
+            this->activate();
+        } else {
+            this->deactivate();
+        }
     }
 
     QMainWindow::changeEvent(e);
 }
 
+void TodoWindow::onChange()
+{
+    CTodo *outdatedTodo = todo;
+    todo = CWrapper::details(todo);
+    delete outdatedTodo;
+
+    reload();
+}
+
 void TodoWindow::reload()
 {
     // Gracefully recover from a task that was deleted behind the scenes
