@@ -1,3 +1,6 @@
+#ifndef TODOWINDOW_H
+#define TODOWINDOW_H
+
 #include "ui_TodoWindow.h"
 
 #include <CTodo.h>
@@ -12,6 +15,8 @@ public:
     TodoWindow(CTodo *todo, QWidget *parent);
     ~TodoWindow();
 
+    void onChange();
+
 private:
     Ui::TodoWindow *ui;
 
@@ -26,3 +31,5 @@ private slots:
     void editTodo();
     void deleteTodo();
 };
+
+#endif // TODOWINDOW_H
